==> jc-1.4.0.tar.gz: javax/swing/JToolBar__24Separator.h <==
// public class javax.swing.JToolBar$Separator

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 5b8de7320d210ab0 javax_swing_JSeparator
// @dep_class 9a81787a3fba4deb javax_swing_JToolBar__24Separator

// header file dependencies
// @dep_header javax_swing_JSeparator

#include "javax/swing/JSeparator.h"

#ifndef _JC_javax_swing_JToolBar__24Separator_H_
#define _JC_javax_swing_JToolBar__24Separator_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_JToolBar__24Separator$sub_refs	_jc_javax_swing_JToolBar__24Separator$sub_refs;
typedef struct _jc_javax_swing_JToolBar__24Separator$sub_nonrefs	_jc_javax_swing_JToolBar__24Separator$sub_nonrefs;
typedef struct _jc_javax_swing_JToolBar__24Separator$refs	_jc_javax_swing_JToolBar__24Separator$refs;
typedef struct _jc_javax_swing_JToolBar__24Separator$nonrefs	_jc_javax_swing_JToolBar__24Separator$nonrefs;
typedef struct _jc_javax_swing_JToolBar__24Separator$object	_jc_javax_swing_JToolBar__24Separator$object;

typedef struct _jc_javax_swing_JToolBar__24Separator$fields_struct	_jc_javax_swing_JToolBar__24Separator$fields_struct;
typedef const struct _jc_javax_swing_JToolBar__24Separator$vmethods	_jc_javax_swing_JToolBar__24Separator$vmethods;
typedef const struct _jc_javax_swing_JToolBar__24Separator$vtable	_jc_javax_swing_JToolBar__24Separator$vtable;
typedef const struct _jc_javax_swing_JToolBar__24Separator$vtype	_jc_javax_swing_JToolBar__24Separator$vtype;

// Class fields structure
struct _jc_javax_swing_JToolBar__24Separator$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JToolBar__24Separator$fields_struct _jc_javax_swing_JToolBar__24Separator$class_fields;

// Constructors
extern void _jc_javax_swing_JToolBar__24Separator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
extern void _jc_javax_swing_JToolBar__24Separator$method$_init$745807a058ea824c(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *, struct _jc_java_awt_Dimension$object *);

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_JToolBar__24Separator$method$getMaximumSize$d24ee7fdb96c1fa3(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_JToolBar__24Separator$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_JToolBar__24Separator$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_JToolBar__24Separator$method$getSeparatorSize$615c47c0bbc9a4d1(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_JToolBar__24Separator$method$getUIClassID$ec5a776389969db1(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
extern void _jc_javax_swing_JToolBar__24Separator$method$setSeparatorSize$ba15bdd68f9bb2b4(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *, struct _jc_java_awt_Dimension$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getMaximumSize$d24ee7fdb96c1fa3;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getMinimumSize$f439289f02165af0;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getSeparatorSize$615c47c0bbc9a4d1;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getUIClassID$ec5a776389969db1;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$setSeparatorSize$ba15bdd68f9bb2b4;

// Virtual methods structure
struct _jc_javax_swing_JToolBar__24Separator$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$d24ee7fdb96c1fa3)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
	struct _jc_java_awt_Dimension$object	*(*getSeparatorSize$615c47c0bbc9a4d1)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
	struct _jc_java_lang_String$object	*(*getUIClassID$ec5a776389969db1)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *);
	void	(*setSeparatorSize$ba15bdd68f9bb2b4)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *, struct _jc_java_awt_Dimension$object *);
};

// Vtable
struct _jc_javax_swing_JToolBar__24Separator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JSeparator$vmethods	javax_swing_JSeparator;
	_jc_javax_swing_JToolBar__24Separator$vmethods	javax_swing_JToolBar__24Separator;
};

// Vtype
struct _jc_javax_swing_JToolBar__24Separator$vtype {
	_jc_type			type;
	_jc_javax_swing_JToolBar__24Separator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToolBar__24Separator$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JToolBar__24Separator$refs {
    _jc_javax_swing_JToolBar__24Separator$sub_refs	javax_swing_JToolBar__24Separator;
    _jc_javax_swing_JSeparator$sub_refs	javax_swing_JSeparator;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToolBar__24Separator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToolBar__24Separator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JSeparator$sub_nonrefs	javax_swing_JSeparator;
    _jc_javax_swing_JToolBar__24Separator$sub_nonrefs	javax_swing_JToolBar__24Separator;
};

// Object instance structure
struct _jc_javax_swing_JToolBar__24Separator$object {
	_jc_javax_swing_JToolBar__24Separator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToolBar__24Separator$vtype	*vtype;
	_jc_javax_swing_JToolBar__24Separator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToolBar__24Separator$vtype _jc_javax_swing_JToolBar__24Separator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToolBar__24Separator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToolBar__24Separator$class_object;

#endif	/* _JC_javax_swing_JToolBar__24Separator_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JToolBar__24Separator.h <==
// public class javax.swing.JToolBar$Separator

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 5b8de7320d210ab0 javax_swing_JSeparator
// @dep_class bb17158fc97feacc javax_swing_JToolBar__24Separator

// header file dependencies
// @dep_header javax_swing_JSeparator

#include "javax/swing/JSeparator.h"

#ifndef _JC_javax_swing_JToolBar__24Separator_H_
#define _JC_javax_swing_JToolBar__24Separator_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_JToolBar__24Separator$sub_refs	_jc_javax_swing_JToolBar__24Separator$sub_refs;
typedef struct _jc_javax_swing_JToolBar__24Separator$sub_nonrefs	_jc_javax_swing_JToolBar__24Separator$sub_nonrefs;
typedef struct _jc_javax_swing_JToolBar__24Separator$refs	_jc_javax_swing_JToolBar__24Separator$refs;
typedef struct _jc_javax_swing_JToolBar__24Separator$nonrefs	_jc_javax_swing_JToolBar__24Separator$nonrefs;
typedef struct _jc_javax_swing_JToolBar__24Separator$object	_jc_javax_swing_JToolBar__24Separator$object;

typedef struct _jc_javax_swing_JToolBar__24Separator$fields_struct	_jc_javax_swing_JToolBar__24Separator$fields_struct;
typedef const struct _jc_javax_swing_JToolBar__24Separator$vmethods	_jc_javax_swing_JToolBar__24Separator$vmethods;
typedef const struct _jc_javax_swing_JToolBar__24Separator$vtable	_jc_javax_swing_JToolBar__24Separator$vtable;
typedef const struct _jc_javax_swing_JToolBar__24Separator$vtype	_jc_javax_swing_JToolBar__24Separator$vtype;

// Class fields structure
struct _jc_javax_swing_JToolBar__24Separator$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JToolBar__24Separator$fields_struct _jc_javax_swing_JToolBar__24Separator$class_fields;

// Constructors
extern void _jc_javax_swing_JToolBar__24Separator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JToolBar__24Separator$method$_init$745807a058ea824c(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *, struct _jc_java_awt_Dimension$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_JToolBar__24Separator$method$getMaximumSize$d24ee7fdb96c1fa3(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_JToolBar__24Separator$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_JToolBar__24Separator$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_JToolBar__24Separator$method$getSeparatorSize$615c47c0bbc9a4d1(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_JToolBar__24Separator$method$getUIClassID$ec5a776389969db1(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JToolBar__24Separator$method$setSeparatorSize$ba15bdd68f9bb2b4(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *, struct _jc_java_awt_Dimension$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getMaximumSize$d24ee7fdb96c1fa3;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getMinimumSize$f439289f02165af0;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getSeparatorSize$615c47c0bbc9a4d1;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$getUIClassID$ec5a776389969db1;
extern _jc_method _jc_javax_swing_JToolBar__24Separator$method_info$setSeparatorSize$ba15bdd68f9bb2b4;

// Virtual methods structure
struct _jc_javax_swing_JToolBar__24Separator$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$d24ee7fdb96c1fa3)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getSeparatorSize$615c47c0bbc9a4d1)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getUIClassID$ec5a776389969db1)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *) _JC_JCNI_ATTR;
	void	(*setSeparatorSize$ba15bdd68f9bb2b4)(_jc_env *, struct _jc_javax_swing_JToolBar__24Separator$object *, struct _jc_java_awt_Dimension$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JToolBar__24Separator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JSeparator$vmethods	javax_swing_JSeparator;
	_jc_javax_swing_JToolBar__24Separator$vmethods	javax_swing_JToolBar__24Separator;
};

// Vtype
struct _jc_javax_swing_JToolBar__24Separator$vtype {
	_jc_type			type;
	_jc_javax_swing_JToolBar__24Separator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToolBar__24Separator$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JToolBar__24Separator$refs {
    _jc_javax_swing_JToolBar__24Separator$sub_refs	javax_swing_JToolBar__24Separator;
    _jc_javax_swing_JSeparator$sub_refs	javax_swing_JSeparator;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToolBar__24Separator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToolBar__24Separator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JSeparator$sub_nonrefs	javax_swing_JSeparator;
    _jc_javax_swing_JToolBar__24Separator$sub_nonrefs	javax_swing_JToolBar__24Separator;
};

// Object instance structure
struct _jc_javax_swing_JToolBar__24Separator$object {
	_jc_javax_swing_JToolBar__24Separator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToolBar__24Separator$vtype	*vtype;
	_jc_javax_swing_JToolBar__24Separator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToolBar__24Separator$vtype _jc_javax_swing_JToolBar__24Separator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToolBar__24Separator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToolBar__24Separator$class_object;

#endif	/* _JC_javax_swing_JToolBar__24Separator_H_ */
